powered by
Generates a phylogenetic tree from a taxon down to a chosen lower taxon.
downto.tree(taxon, downto, key = NULL, db = "ncbi")
The higher taxon from which the tree will start. (i.e. Family, Genus)
The lowest level of taxonomy wanted. Must be lower than the one in taxon argument. Only species can be outputed from the Mammals tree.
API key. To create one use taxize::use_entrez().
Database used. Default is "ncbi". For possible datbases see ?taxize::downstream
# NOT RUN { #Choose a certain taxon and the level you want the tree to stop downto.tree("Cervidae", "species") # }
Run the code above in your browser using DataLab