Learn R Programming

aptg (version 0.1.1)

taxa.tree: Tree from taxa

Description

Generates a tree and distance matrix from a list of species names. There are reference trees for mammals and angiosperms. The input species will be sorted by reference trees.

Usage

taxa.tree(species)

Arguments

species

a list of species that is to be included in the phylogenetic tree.

Examples

Run this code
# NOT RUN {
#Choose a list of string of species that you want to have in a phylogenetic tree.
taxa.tree(species = c("Canis lupus", "Canis latrans", "Acer saccharum", "Castor canadensis",
"Alces alces", "Acer rubrum",
"Vulpes vulpes", "Salix babylonica", "Odocoileus virginianus", "Betula alleghaniensis",
"Rangifer tarandus","Juniperus occidentalis"))
# }

Run the code above in your browser using DataLab